import requests
from typing import Dict


__all__ = ["AcrossException", "AcrossAPI"]


class AcrossException(Exception):
    """Across exception."""

    pass


class AcrossAPI:

    BASEURL = "https://across.to/api"

    def suggested_fees(
        self, l2Token: str, chainId: int, amount: int
    ) -> Dict[str, int]:
        """get suggested fees for a given amount of l2Token.

        Args:
            l2Token (str): Address of L2 Token Contract to Transfer. For ETH use address `0x0`.
            chainId (int): Chain ID to transfer from.
            amount (int): Amount of the token to transfer.
                          Note: this amount is in the native decimals of the token.
                          So, for ETH this would be the amount of human-readable ETH multiplied by `1e18`.
                          For USDC, you would multiply the number of human-readable USDC by `1e6`.

        Returns:
            suggested fees for slow and instant relay.
                - slowFeePct (int): Fee for slow relay.
                - instantFeePct (int): Fee for instant relay.

        Raises:
            AcrossException: if the request fails.
                - 400: if either the slow fee or the instant fee exceeds 25% of the amount.
                - 400: invalid input.
                - 500: an unexpected error within the API.
        """
        url = f"{self.BASEURL}/suggested-fees"
        params = {"amount": amount, "chainId": chainId, "l2Token": l2Token}
        response = requests.get(url, params=params)
        if response.status_code != 200:
            raise AcrossException(
                f"Failed to get fees for {l2Token}: {response.text}"
            )
        return response.json()


if __name__ == "__main__":
    api = AcrossAPI()
    print(
        api.suggested_fees(
            "0x7f5c764cbc14f9669b88837ca1490cca17c31607", 10, 1000000000
        )
    )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['across']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.26.0,<3.0.0']

setup_kwargs = {
    'name': 'across-py',
    'version': '0.0.2',
    'description': 'across sdk in python',
    'long_description': '# Across\n\nAcross is the fastest, cheapest and most secure cross-chain bridge. It is a system that uses UMA contracts to quickly move tokens across chains. This contains various utilities to support applications on across.\n\n## How to use\n\nUse across official API to get suggested fees.\n```py\n>>> import across\n>>> a = across.AcrossAPI()\n>>> a.suggested_fees("0x7f5c764cbc14f9669b88837ca1490cca17c31607", 10, 1000000000)\n{\'slowFeePct\': \'43038790000000000\', \'instantFeePct\': \'5197246000000000\'}\n```\n\n## How to build and test\n\nInstall poetry and install the dependencies:\n\n```shell\npip3 install poetry\n\npoetry install\n\n# test\npython -m unittest\n\n# local install and test\npip3 install twine\npython3 -m twine upload --repository testpypi dist/*\npip3 install --index-url https://test.pypi.org/simple/ --no-deps across\n```\n',
    'author': 'qiwihui',
    'author_email': 'qwh005007@gmail.com',
    'maintainer': 'qiwihui',
    'maintainer_email': 'qwh005007@gmail.com',
    'url': 'https://github.com/qiwihui/across-py',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
